@@ -208,16 +208,25 @@ class CameraInput(TypedDict):
 
 CameraRoles = Literal["detect", "record", "stream", "snapshot", "none"]
 
-CameraExtension = Literal[
-    "hub",
+CameraExtensionWithoutHub = Literal[
     "prebuffer",
     "motionDetection",
     "objectDetection",
     "audioDetection",
     "ptz",
-    "intercom",
 ]
 
+CameraExtension = Union[CameraExtensionWithoutHub, Literal["hub"]]
+
+
+class PluginContract(TypedDict):
+    extension: NotRequired[CameraExtension]
+    supportAdditionalCameras: NotRequired[bool]
+    builtIns: NotRequired[list[CameraExtensionWithoutHub]]
+    dependencies: list[str]
+    pythonVersion: NotRequired[str]
+
+
 Point = tuple[float, float]
 
 ZoneType = Literal["intersect", "contain"]
@@ -288,7 +297,6 @@ class Camera(TypedDict):
     hasMotionDetector: bool
     hasObjectDetector: bool
     hasPrebuffer: bool
-    hasIntercom: bool
     hasPtz: bool
     sources: list[CameraInput]
     frameWorkerSettings: CameraFrameWorkerSettings
@@ -313,7 +321,6 @@ CameraPublicProperties = Literal[
     "hasMotionDetector",
     "hasObjectDetector",
     "hasPrebuffer",
-    "hasIntercom",
     "hasPtz",
     "sources",
     "frameWorkerSettings",
@@ -637,16 +644,20 @@ Container = Literal["mpegts", "mp4"]
 
 TalkbackCodec = Literal["PCMA", "PCMU", "opus"]
 
+Interfaces = Literal["camera", "ptz", "prebuffer", "audioDetector", "motionDetector", "objectDetector"]
+
 
 class CameraDelegate(metaclass=ABCMeta):
     @abstractmethod
-    async def snapshotRequest(self, request_id: str) -> Union[bytes, None]: ...
+    async def snapshotRequest(self, request_id: str, source_name: str) -> Union[bytes, None]: ...
 
     @abstractmethod
-    async def startStream(self, request_id: str) -> None: ...
+    async def startStream(
+        self, request_id: str, source_name: str, video_port: int, audio_port: int
+    ) -> None: ...
 
     @abstractmethod
-    async def stopStream(self, request_id: str) -> None: ...
+    async def stopStream(self, request_id: str, source_name: str) -> None: ...
 
     @abstractmethod
     async def onTalkbackSdp(
@@ -656,8 +667,14 @@ class CameraDelegate(metaclass=ABCMeta):
     @abstractmethod
     async def onTalkbackRtp(self, request_id: str, source_name: str, rtp: bytes) -> None: ...
 
-    @abstractmethod
-    async def reboot(self) -> None: ...
+
+CameraDelegateMethodNames = Literal[
+    "snapshotRequest",
+    "startStream",
+    "stopStream",
+    "onTalkbackSdp",
+    "onTalkbackRtp",
+]
 
 
 class CameraPrebufferDelegate(metaclass=ABCMeta):
@@ -665,13 +682,48 @@ class CameraPrebufferDelegate(metaclass=ABCMeta):
     async def getStreamInfo(self, source_name: str) -> Optional[StreamInfo]: ...
 
 
-class CameraControllerOptions(TypedDict):
-    delegate: Optional[CameraDelegate]
-    prebuffer_delegate: Optional[CameraPrebufferDelegate]
+CameraPrebufferDelegateMethodNames = Literal["getStreamInfo"]
 
 
-class CameraDelegateController(Protocol):
-    def configure_controller(self, controller_options: CameraControllerOptions) -> None: ...
+class CameraPTZDelegate(metaclass=ABCMeta):
+    @abstractmethod
+    async def moveAbsolute(self, pan: float, tilt: float, zoom: float) -> None: ...
+
+    @abstractmethod
+    async def moveRelative(self, pan: float, tilt: float, zoom: float) -> None: ...
+
+    @abstractmethod
+    async def moveContinuous(self, pan: float, tilt: float, zoom: float) -> None: ...
+
+    @abstractmethod
+    async def stop(self) -> None: ...
+
+
+CameraPTZDelegateMethodNames = Literal["moveAbsolute", "moveRelative", "moveContinuous", "stop"]
+
+
+class CameraMotionDetectionDelegate(metaclass=ABCMeta):
+    @abstractmethod
+    async def detectImage(self, image: bytes) -> list[Detection]: ...
+
+
+CameraMotionDetectionDelegateMethodNames = Literal["detectImage"]
+
+
+class CameraObjectDetectionDelegate(metaclass=ABCMeta):
+    @abstractmethod
+    async def detectImage(self, image: bytes) -> list[Detection]: ...
+
+
+CameraObjectDetectionDelegateMethodNames = Literal["detectImage"]
+
+
+class CameraAudioDetectionDelegate(metaclass=ABCMeta):
+    @abstractmethod
+    async def detectAudio(self, audio: bytes) -> bool: ...
+
+
+CameraAudioDetectionDelegateMethodNames = Literal["detectAudio"]
 
 
 class CameraSource(Protocol):
@@ -807,7 +859,6 @@ class CameraDevice(Protocol):
     has_object_detector: bool
     has_ptz: bool
     has_prebuffer: bool
-    has_intercom: bool
 
     on_connected: Observable[bool]
     on_light_switched: Observable[LightState]
@@ -823,12 +874,34 @@ class CameraDevice(Protocol):
     recording_source: CameraSource
     detection_source: CameraSource
 
-    camera_controller: CameraDelegateController
+    ptzDelegate: CameraPTZDelegate
+    audioDetectorDelegate: CameraAudioDetectionDelegate
+    motionDetectorDelegate: CameraMotionDetectionDelegate
+    objectDetectorDelegate: CameraObjectDetectionDelegate
+
+    @overload
+    async def set_delegate(self, name: Literal["cameraDelegate"], delegate: CameraDelegate) -> None: ...
+    @overload
+    async def set_delegate(
+        self, name: Literal["prebufferDelegate"], delegate: CameraPrebufferDelegate
+    ) -> None: ...
+    @overload
+    async def set_delegate(self, name: Literal["ptzDelegate"], delegate: CameraPTZDelegate) -> None: ...
+    @overload
+    async def set_delegate(
+        self, name: Literal["audioDetectorDelegate"], delegate: CameraAudioDetectionDelegate
+    ) -> None: ...
+    @overload
+    async def set_delegate(
+        self, name: Literal["motionDetectorDelegate"], delegate: CameraMotionDetectionDelegate
+    ) -> None: ...
+    @overload
+    async def set_delegate(
+        self, name: Literal["objectDetectorDelegate"], delegate: CameraObjectDetectionDelegate
+    ) -> None: ...
 
-    def configure_controller(self, controller_options: CameraControllerOptions) -> None: ...
     async def connect(self) -> None: ...
     async def disconnect(self) -> None: ...
-    async def reboot(self) -> None: ...
     async def snapshot(self, force_new: Optional[bool] = None) -> bytes: ...
     async def get_frames(self, prebuffer_duration: int = 0) -> AsyncGenerator[VideoFrame, None]: ...
     async def get_motion_frames(self) -> AsyncGenerator[MotionFrame, None]: ...
@@ -847,13 +920,16 @@ class CameraDevice(Protocol):
         BatteryState,
     ]: ...
 
+    async def add_camera_source(self, source: "CameraInputSettings") -> None: ...
+    async def update_camera_source(self, source_id: str, source: "CameraInputSettingsPartial") -> None: ...
+    async def remove_camera_source(self, source_id: str) -> None: ...
+
     @overload
     async def update_state(
         self,
         state_name: Literal["light"],
         event_data: LightSetEvent,
     ) -> None: ...
-
     @overload
     async def update_state(
         self,
@@ -861,35 +937,30 @@ class CameraDevice(Protocol):
         event_data: MotionSetEvent,
         frame: Optional[VideoFrame] = None,
     ) -> None: ...
-
     @overload
     async def update_state(
         self,
         state_name: Literal["audio"],
         event_data: AudioSetEvent,
     ) -> None: ...
-
     @overload
     async def update_state(
         self,
         state_name: Literal["object"],
         event_data: ObjectSetEvent,
     ) -> None: ...
-
     @overload
     async def update_state(
         self,
         state_name: Literal["doorbell"],
         event_data: DoorbellSetEvent,
     ) -> None: ...
-
     @overload
     async def update_state(
         self,
         state_name: Literal["siren"],
         event_data: SirenSetEvent,
     ) -> None: ...
-
     @overload
     async def update_state(
         self,
@@ -931,7 +1002,6 @@ class CameraDevice(Protocol):
     def on_state_change(  # type: ignore
         self, state_name: StateNames
     ) -> Observable[CameraStateChangedObject[StateValue]]: ...
-
     def on_property_change(
         self, property: Union[CameraPublicProperties, list[CameraPublicProperties]]
     ) -> Observable[CameraPropertyObservableObject]: ...
@@ -959,23 +1029,23 @@ class CameraInputSettings(TypedDict):
     urls: list[str]
 
 
+class CameraInputSettingsPartial(TypedDict, total=False):
+    # _id: str
+    name: str
+    roles: list[CameraRoles]
+    urls: list[str]
+
+
 class CameraConfigInputSettings(TypedDict):
     name: str
     roles: list[CameraRoles]
     urls: NotRequired[list[str]]
 
 
-class CameraConfigWithoutSources(BaseCameraConfig):
+class CameraConfig(BaseCameraConfig):
     sources: list[CameraConfigInputSettings]
 
 
-class CameraConfigWithDelegate(BaseCameraConfig):
-    delegate: NotRequired[CameraDelegate]
-
-
-CameraConfig = CameraConfigWithoutSources
-
-
 # events and callbacks
 CameraSelectedCallback = Union[
     Callable[[CameraDevice, CameraExtension], None],
